Coverage report

File | class | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | --- | ---
aiopromql/__init__.py | (no class) | 3 | 0 | 0 | 0 | 0 | 100%
aiopromql/client.py | PrometheusClientBase | 2 | 0 | 0 | 0 | 0 | 100%
aiopromql/client.py | PrometheusSync | 12 | 0 | 0 | 0 | 0 | 100%
aiopromql/client.py | PrometheusAsync | 15 | 1 | 0 | 2 | 1 | 88%
aiopromql/client.py | (no class) | 22 | 0 | 0 | 0 | 0 | 100%
aiopromql/models/__init__.py | (no class) | 0 | 0 | 0 | 0 | 0 | 100%
aiopromql/models/core.py | MetricLabelSet | 8 | 1 | 0 | 2 | 0 | 90%
aiopromql/models/core.py | TimeSeriesPoint | 2 | 1 | 0 | 0 | 0 | 50%
aiopromql/models/core.py | TimeSeries | 10 | 2 | 0 | 0 | 0 | 80%
aiopromql/models/core.py | (no class) | 24 | 0 | 0 | 0 | 0 | 100%
aiopromql/models/prometheus.py | VectorResultModel | 0 | 0 | 0 | 0 | 0 | 100%
aiopromql/models/prometheus.py | MatrixResultModel | 0 | 0 | 0 | 0 | 0 | 100%
aiopromql/models/prometheus.py | VectorDataModel | 6 | 0 | 0 | 2 | 0 | 100%
aiopromql/models/prometheus.py | MatrixDataModel | 7 | 0 | 0 | 4 | 0 | 100%
aiopromql/models/prometheus.py | PrometheusResponseModel | 1 | 0 | 0 | 0 | 0 | 100%
aiopromql/models/prometheus.py | (no class) | 22 | 0 | 0 | 0 | 0 | 100%
aiopromql/utils.py | (no class) | 10 | 0 | 0 | 4 | 0 | 100%
Total |  | 144 | 5 | 0 | 14 | 1 | 96%

No items found using the specified filter.